@@ -1,4 +1,4 @@
-/* electric_field.h -- This file is part of Archimedes release 0.0.5.
+/* electric_field.h -- This file is part of Archimedes release 0.0.9.
    Archimedes is a simulator for Submicron 2D Silicon/GaAs
    Devices. It implements the Monte Carlo method and a simplfied
    version of the MEP model (Maximum Entropy Principle model)
@@ -6,11 +6,11 @@
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
 
-   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -26,7 +26,7 @@
 
 // ######################################################
 // Created on 10 Mar.2004, Siracusa, J.M.Sellier
-// Last modif. : 07 Apr.2005, Siracusa, J.M.Sellier
+// Last modif. : 07 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Computation of the electrostatic potential,
@@ -34,7 +34,7 @@
 // by means of the computation of the stationary 
 // solution of a pseudo-transient Poisson equation.
 // For more information see the manual of 
-// GNU Archimedes release 0.0.5.
+// GNU Archimedes release 0.0.9.
 
 void 
 Electric_Field(void)
@@ -43,11 +43,10 @@ Electric_Field(void)
 
  real factor,kappa,deltat,rho;
 
+ factor=0.9;
+
  PoissonBCs();
 // ===============================
- factor=0.9;
- kappa=(epsMATERIAL)/Q;
- deltat=factor*0.5/kappa/(1./(dx*dx)+1./(dy*dy));
 // calcolo del potenziale "stazionario"
  for(i=1;i<=POISSONITMAX;i++){
 // Eventual Upper SiO2
@@ -80,24 +79,29 @@ Electric_Field(void)
 // ***
     for(k=2;k<=sio2ny;k++)
      for(j=2;j<=sio2nx;j++){
+       kappa=(EPSR[i_dom[j][k]]*EPS0)/Q;
+       deltat=factor*0.5/kappa/(1./(dx*dx)+1./(dy*dy));
        SIO2[0][j][k]=SIO2[0][j][k]+deltat*kappa*
           ((SIO2[0][j+1][k]-2.0*SIO2[0][j][k]+SIO2[0][j-1][k])/(dx*dx)
           +(SIO2[0][j][k+1]-2.0*SIO2[0][j][k]+SIO2[0][j][k-1])/(dy*dy));
      }
    }
 // ###
-// Silicon/GaAs domain
+// Semiconductor domain
    PoissonBCs();
    for(j=0;j<=ny+2;j++)
      for(k=0;k<=nx+2;k++)
        PSI[k][j]=u2d[k][j][0];
-   for(k=2;k<=ny;k++)
-     for(j=2;j<=nx;j++){
-       rho=(u2d[j][k][1]-N_D[j][k]-h2d[j][k][1]+N_H[j][k]);
-       u2d[j][k][0]=PSI[j][k]-deltat*rho+deltat*kappa*
-             ((PSI[j+1][k]-2.0*PSI[j][k]+PSI[j-1][k])/(dx*dx)
-             +(PSI[j][k+1]-2.0*PSI[j][k]+PSI[j][k-1])/(dy*dy));
-     }
+    for(k=2;k<=ny;k++)
+      for(j=2;j<=nx;j++){
+        rho=(u2d[j][k][1]-N_D[j][k]-h2d[j][k][1]+N_H[j][k]);
+        kappa=(EPSR[i_dom[j][k]]*EPS0)/Q;
+        deltat=factor*0.5/kappa/(1./(dx*dx)+1./(dy*dy));
+        u2d[j][k][0]=PSI[j][k]-deltat*rho+deltat*kappa*
+              ((PSI[j+1][k]-2.0*PSI[j][k]+PSI[j-1][k])/(dx*dx)
+              +(PSI[j][k+1]-2.0*PSI[j][k]+PSI[j][k-1])/(dy*dy));
+      }
+
 // Eventual lower SiO2
 // ###
    if(SIO2_DOWN_FLAG==1)
@@ -128,6 +132,8 @@ Electric_Field(void)
 // ***
     for(k=2;k<=sio2ny;k++)
      for(j=2;j<=sio2nx;j++){
+       kappa=(EPSR[i_dom[j][k]]*EPS0)/Q;
+       deltat=factor*0.5/kappa/(1./(dx*dx)+1./(dy*dy));
        SIO2[1][j][k]=SIO2[1][j][k]+deltat*kappa*
           ((SIO2[1][j+1][k]-2.0*SIO2[1][j][k]+SIO2[1][j-1][k])/(dx*dx)
           +(SIO2[1][j][k+1]-2.0*SIO2[1][j][k]+SIO2[1][j][k-1])/(dy*dy));
@@ -152,23 +158,25 @@ Electric_Field(void)
 
 // Computation of the X-component of the electric Field
 // ====================================================
-  for(k=1;k<=ny+1;k++)
-   for(j=2;j<=nx;j++)
-    E[j][k][0]=-0.5*(u2d[j+1][k][0]-u2d[j-1][k][0])/dx;
-  for(k=1;k<=ny+1;k++){
-    E[1][k][0]=E[2][k][0];
-    E[nx+1][k][0]=E[nx][k][0];
-  }
+    for(k=1;k<=ny+1;k++)
+     for(j=2;j<=nx;j++){
+      E[j][k][0]=-0.5*(u2d[j+1][k][0]-u2d[j-1][k][0])/dx;
+     }
+    for(k=1;k<=ny+1;k++){
+      E[1][k][0]=E[2][k][0];
+      E[nx+1][k][0]=E[nx][k][0];
+    }
 
 // Computation of the Y-component of the electric Field
 // ====================================================
-  for(k=2;k<=ny;k++)
-   for(j=1;j<=nx+1;j++)
-    E[j][k][1]=-0.5*(u2d[j][k+1][0]-u2d[j][k-1][0])/dy;
-  for(j=1;j<=nx+1;j++){
-    E[j][1][1]=E[j][2][1];
-    E[j][ny+1][1]=E[j][ny][1];
-  }
+    for(k=2;k<=ny;k++)
+     for(j=1;j<=nx+1;j++){
+      E[j][k][1]=-0.5*(u2d[j][k+1][0]-u2d[j][k-1][0])/dy;
+     }
+    for(j=1;j<=nx+1;j++){
+      E[j][1][1]=E[j][2][1];
+      E[j][ny+1][1]=E[j][ny][1];
+    }
 }
 
 // ==============================================================
