@@ -27,7 +27,7 @@
 // File Name : electron_relaxation.c
 // Version   : release 0.0.3
 // Date of Creation : 12 Aug.2004, Siracusa, Italy, Jean Michel Sellier
-// Last Revision : 03 Mar.2005, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 10 Aug.2007, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -56,15 +56,15 @@ void electron_relaxation_step(void)
   for(i=ND;i<=nx+ND;i++)
    for(j=ND;j<=ny+ND;j++){
      t=(2./3.)*(u2d[i][j][4]/u2d[i][j][1])/KB;
-     ktaup=M*mstar*MIU0*TL/Q;
+     ktaup=M*MSTAR[i_dom[i][j]][1]*MIU0*TL/Q;
      ktauw=MIU0*TL*KB/(Q*VS*VS);
      taup=ktaup/t;
      u2d[i][j][4]+=-DT/50.*(Q*(u2d[i][j][2]*E[i-1][j-1][0]
                   +u2d[i][j][3]*E[i-1][j-1][1])
                   +u2d[i][j][1]*1.5*KB*(t-TL)/tauwi(1.5*KB*t));
-     u2d[i][j][2]+=-DT/50.*(u2d[i][j][1]*Q*E[i-1][j-1][0]/(M*mstar)
+     u2d[i][j][2]+=-DT/50.*(u2d[i][j][1]*Q*E[i-1][j-1][0]/(M*MSTAR[i_dom[i][j]][1])
                   +u2d[i][j][2]/taup);
-     u2d[i][j][3]+=-DT/50.*(u2d[i][j][1]*Q*E[i-1][j-1][1]/(M*mstar)
+     u2d[i][j][3]+=-DT/50.*(u2d[i][j][1]*Q*E[i-1][j-1][1]/(M*MSTAR[i_dom[i][j]][1])
                   +u2d[i][j][3]/taup);
    }
 // DT*=2.;
