@@ -1,16 +1,15 @@
-/* saveoutput2dgnuplot.h -- This file is part of Archimedes release 0.0.8.
-   Archimedes is a simulator for Submicron 2D III-V semiconductor
+/* saveoutput2dgnuplot.h -- This file is part of Archimedes release 0.0.7.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
-   of effective potential method. It is now able to simulate applied
-   magnetic fields along with self consistent Faraday equation.
+   of effective potential method.
 
    Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
+   the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -26,7 +25,7 @@
 
 // ######################################################
 // Created on 10 Sep.2004, Siracusa (Italy), J.M.Sellier
-// Last modif. : 18 Aug.2007, Siracusa (Italy), J.M.Sellier
+// Last modif. : 10 Aug.2007, Siracusa (Italy), J.M.Sellier
 // ######################################################
 
 // Here we save all the macroscopic variables 
@@ -55,7 +54,7 @@
 void
 SaveOutput2DGNUPLOT(int je)
 {
- char s[50];
+ char s[150];
  FILE *fp;
  FILE *up;
  FILE *vp;
@@ -66,11 +65,9 @@ SaveOutput2DGNUPLOT(int je)
  FILE *qp;
  FILE *fG;
  FILE *fL;
- FILE *fB;
-
  register int i,j;
 
-if(Material==SILICON || Material==GERMANIUM){
+//if(Material==SILICON || Material==GERMANIUM){
  if(je<=9){
    sprintf(s,"density00%d.xyz",je);
    fp=fopen(s,"w");
@@ -88,8 +85,6 @@ if(Material==SILICON || Material==GERMANIUM){
    lyp=fopen(s,"w");
    sprintf(s,"quantum_potential00%d.xyz",je);
    qp=fopen(s,"w");
-   sprintf(s,"magnetic_field00%d.xyz",je);
-   fB=fopen(s,"w");
  }
  else if(je>9 && je<=99){
    sprintf(s,"density0%d.xyz",je);
@@ -108,8 +103,6 @@ if(Material==SILICON || Material==GERMANIUM){
    lyp=fopen(s,"w");
    sprintf(s,"quantum_potential0%d.xyz",je);
    qp=fopen(s,"w");
-   sprintf(s,"magnetic_field0%d.xyz",je);
-   fB=fopen(s,"w");
  }
  else{
    sprintf(s,"density%d.xyz",je);
@@ -128,8 +121,6 @@ if(Material==SILICON || Material==GERMANIUM){
    lyp=fopen(s,"w");
    sprintf(s,"quantum_potential%d.xyz",je);
    qp=fopen(s,"w");
-   sprintf(s,"magnetic_field%d.xyz",je);
-   fB=fopen(s,"w");
  }
 // Save the Monte Carlo results
  if(Model_Number==MCE || Model_Number==MCEH){
@@ -163,14 +154,6 @@ if(Material==SILICON || Material==GERMANIUM){
       fprintf(lp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,PSI[i][j]);
       fprintf(lp,"\n");
   }
-// Magnetic Field
-// ==============
-  for(j=1;j<=ny+1;j++){
-    for(i=1;i<=nx+1;i++)
-      fprintf(fB,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,B[i][j]);
-      fprintf(fB,"\n");
-  }
-
 // X-component of electric field
 // =============================
   for(j=1;j<=ny+1;j++){
@@ -212,7 +195,6 @@ if(Material==SILICON || Material==GERMANIUM){
    fclose(lyp);
    fclose(ep);
    fclose(qp);
-   fclose(fB);
   }
 // Save the Hybrid MEP results
  if(Model_Number==MEPE || Model_Number==MEPEH){
@@ -247,14 +229,6 @@ if(Material==SILICON || Material==GERMANIUM){
       fprintf(lp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,PSI[i][j]);
       fprintf(lp,"\n");
   }
-// magnetic field
-// ==============
-  for(j=1;j<=ny+1;j++){
-    for(i=1;i<=nx+1;i++)
-      fprintf(fB,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,B[i][j]);
-      fprintf(fB,"\n");
-  }
-
 // X-component of electric field
 // =============================
   for(j=1;j<=ny+1;j++){
@@ -296,11 +270,10 @@ if(Material==SILICON || Material==GERMANIUM){
    fclose(lyp);
    fclose(ep);
    fclose(qp);
-   fclose(fB);
   }
- }
+// }
 // ****************************************************************
-if(Material==GAAS){
+/*if(Material==GAAS){
  if(je<=9){
    sprintf(s,"density00%d.xyz",je);
    fp=fopen(s,"w");
@@ -322,8 +295,6 @@ if(Material==GAAS){
    lyp=fopen(s,"w");
    sprintf(s,"quantum_potential00%d.xyz",je);
    qp=fopen(s,"w");
-   sprintf(s,"magnetic_field00%d.xyz",je);
-   fB=fopen(s,"w"); 
  }
  else if(je>9 && je<=99){
    sprintf(s,"density0%d.xyz",je);
@@ -346,8 +317,6 @@ if(Material==GAAS){
    lyp=fopen(s,"w");
    sprintf(s,"quantum_potential0%d.xyz",je);
    qp=fopen(s,"w");
-   sprintf(s,"magnetic_field0%d.xyz",je);
-   fB=fopen(s,"w");
  }
  else{
    sprintf(s,"density%d.xyz",je);
@@ -370,8 +339,6 @@ if(Material==GAAS){
    lyp=fopen(s,"w");
    sprintf(s,"quantum_potential%d.xyz",je);
    qp=fopen(s,"w");
-   sprintf(s,"magnetic_field%d.xyz",je);
-   fB=fopen(s,"w");
  }
 
 // Electron Density Output
@@ -418,13 +385,6 @@ if(Material==GAAS){
      fprintf(lp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,PSI[i][j]);
      fprintf(lp,"\n");
  }
-// Magnetic Field
-// ==============
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(fB,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,B[i][j]);
-     fprintf(fB,"\n");
- }
 // X-component of electric field
 // =============================
  for(j=1;j<=ny+1;j++){
@@ -468,8 +428,7 @@ if(Material==GAAS){
  fclose(qp);
  fclose(fG);
  fclose(fL);
- fclose(fB);
- }
+ }*/
 }
 
 // ============================================================
