@@ -1,11 +1,11 @@
-/* scattering.h -- This file is part of Archimedes release 0.0.2.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+/* scattering.h -- This file is part of Archimedes release 0.0.7.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
 
-   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,16 +25,17 @@
 
 // ######################################################
 // Created on 06 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 28 Jan.2005, Siracusa, J.M.Sellier
+// Last modif. : 08 Aug.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // calculation of the various scattering process
-// In the present version (0.0.2) we take into account
+// In the present version (0.0.7) we take into account
 // acoustic phonons scattering and all the non-polar optical phonons
-// scattering which are the most relevant in Silicon devices.
+// scattering which are the most relevant in Silicon devices,
+// Gallium Arsenide and Germanium.
 
 void
-scat(void)
+scat(int Material)
 {
  int j=0;
  register int i,ie=0;
@@ -45,12 +46,12 @@ scat(void)
 
   if(IV==9) return;
 
-// Silicon Scattering Selection
-// ############################
- if(Material==SILICON){
+// One-valley Materials Scattering Selection
+// #########################################
+ if(NOVALLEY[Material]==1){
   ksquared=KX*KX+KY*KY+KZ*KZ;
-  thesquareroot=sqrt(1.+4.*alphaSILICON*HHM[0]*ksquared);
-  superparticle_energy=(thesquareroot-1.)/(2.*alphaSILICON);
+  thesquareroot=sqrt(1.+4.*alphaK[Material][1]*HHM[Material][1]*ksquared);
+  superparticle_energy=(thesquareroot-1.)/(2.*alphaK[Material][1]);
   if(superparticle_energy<=0.) return;
   ie=((int)(superparticle_energy/DE))+1;
   if(ie>DIME) ie=DIME;
@@ -60,25 +61,33 @@ scat(void)
 // Non-Polar optical phonons
   for(i=1;i<=6;i++){
 // Emission of an optical phonon
-    if(r1<=SWK[0][i*2-1][ie] && j==0){
-       finalenergy=superparticle_energy-SiHWO[i-1];
+    if(r1<=SWK[Material][0][i*2-1][ie] && j==0){
+       finalenergy=superparticle_energy-HWO[Material][i-1];
        j=1;
     }
 // Absorbation of an optical phonon
-    if((r1<=SWK[0][i*2][ie]) && j==0){
-       finalenergy=superparticle_energy+SiHWO[i-1];
+    if((r1<=SWK[Material][0][i*2][ie]) && j==0){
+       finalenergy=superparticle_energy+HWO[Material][i-1];
        j=1;
     }
   }
 // Acoustic phonon
-  if((r1<=SWK[0][13][ie]) && j==0){
+  if((r1<=SWK[Material][0][13][ie]) && j==0){
      finalenergy=superparticle_energy;
      j=1;
   }
-  if((finalenergy<=0.) || j==0) return;
+// Impact ionization
+/*  if((r1<=SWK[Material][0][14][ie]) && j==0){
+     ra1=0.5-rnd();
+     ra2=pow(rnd(),2.);
+     finalenergy=bbb*superparticle_energy*(1.0+aaa*ra1*ra2);
+     finalenergy=superparticle_energy-finalenergy;
+     j=1;
+  }
+  if((finalenergy<=0.) || j==0) return;*/
 
 // determination of the final states
-  finalk = SMH[0]*sqrt(finalenergy*(1.+alphaSILICON*finalenergy));
+  finalk = SMH[Material][1]*sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
   cosinus = 1.-2.*rnd();
   sinus = sqrt(1.-cosinus*cosinus);
   fai = 2.*PI*rnd();
@@ -88,28 +97,29 @@ scat(void)
   return;
  }
 
-// Gallium Arsenide Scattering Selection
-// #####################################
- if(Material==GAAS){
+// 2-valleys materials Scattering Selection
+// ########################################
+ if(NOVALLEY[Material]==2){
    ksquared=KX*KX+KY*KY+KZ*KZ;
    ki=sqrt(ksquared);
-   thesquareroot=sqrt(1.+4.*AF[IV]*HHM[IV]*ksquared);
-   superparticle_energy=(thesquareroot-1.)/(2.*AF[IV]);
+   thesquareroot=sqrt(1.+4.*alphaK[Material][IV]*HHM[Material][IV]*ksquared);
+   superparticle_energy=(thesquareroot-1.)/(2.*alphaK[Material][IV]);
   if(superparticle_energy<=0.) return;
   ie=((int)(superparticle_energy/DE))+1;
   if(ie>DIME) ie=DIME;
 
-// Selection of scattering process in the GAMMA-Valley
+// Selection of scattering process in the first-Valley
 // ===================================================
   if(IV==1){
     r1 = rnd();
 // Non-Polar optical phonons
 // Emission of an optical phonon
-      if(r1<=SWK[1][1][ie] && j==0){
-         finalenergy=superparticle_energy-GAASHWO;
+      if(r1<=SWK[Material][1][1][ie] && j==0){
+         finalenergy=superparticle_energy-HWO[Material][0];
+         if(finalenergy<0.) return;
          j=1;
 // linea 20
-       kf=SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        f=2.*ki*kf/(ki-kf)/(ki-kf);
        if(f<=0.) return;
        cb=(1.+f-pow(1.+2.*f,rnd()))/f;
@@ -135,12 +145,14 @@ scat(void)
        KZ=a32*x2+a33*x3;
        return;
       }
+
 // Absorption of an optical phonon
-      if((r1<=SWK[1][2][ie]) && j==0){
-         finalenergy=superparticle_energy+GAASHWO;
+      if((r1<=SWK[Material][1][2][ie]) && j==0){
+         finalenergy=superparticle_energy+HWO[Material][0];
+         if(finalenergy<0.) return;
          j=1;
 // linea 20
-       kf=SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        f=2.*ki*kf/(ki-kf)/(ki-kf);
        if(f<=0.) return;
        cb=(1.+f-pow((1.+2.*f),rnd()))/f;
@@ -167,13 +179,13 @@ scat(void)
        return;
       }
 // Emission
-      if((r1<=SWK[1][3][ie]) && j==0){
-         finalenergy=superparticle_energy-GAASHWO+EC[1]-EC[2];
+      if((r1<=SWK[Material][1][3][ie]) && j==0){
+         finalenergy=superparticle_energy-HWO[Material][0]+EC[Material][1]-EC[Material][2];
          if(finalenergy<0.) return;
          IV=2;
          j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -183,13 +195,13 @@ scat(void)
        return;
       }
 // Absorption
-      if((r1<=SWK[1][4][ie]) && j==0){
-         finalenergy=superparticle_energy+GAASHWO+EC[1]-EC[2];
+      if((r1<=SWK[Material][1][4][ie]) && j==0){
+         finalenergy=superparticle_energy+HWO[Material][0]+EC[Material][1]-EC[Material][2];
          if(finalenergy<0.) return;
          IV=2;
          j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -199,12 +211,13 @@ scat(void)
        return;
       }
 // Acoustic phonon
-    if((r1<=SWK[1][5][ie]) && j==0){
+    if((r1<=SWK[Material][1][5][ie]) && j==0){
        finalenergy=superparticle_energy;
+       if(finalenergy<0.) return;
        finalk=sqrt(ksquared);
        j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -214,8 +227,9 @@ scat(void)
        return;
     }
 // Impurity scattering
-    if((r1<=SWK[1][6][ie]) && j==0){
+    if((r1<=SWK[Material][1][6][ie]) && j==0){
      finalenergy=superparticle_energy;
+     if(finalenergy<0.) return;
      r2=rnd();
      cb=1.-r2/(0.5+(1.-r2)*ksquared/QD2);
      kf=ki;
@@ -241,10 +255,18 @@ scat(void)
      KZ=a32*x2+a33*x3;
      return;
     }
-    if((finalenergy<=0.) || j==0) return;
+// Impact ionization
+/*    if((r1<=SWK[Material][1][7][ie]) && j==0){
+       ra1=0.5-rnd();
+       ra2=pow(rnd(),2.);
+       finalenergy=bbb*superparticle_energy*(1.0+aaa*ra1*ra2);
+       finalenergy=superparticle_energy-finalenergy;
+       j=1;
+    }
+    if((finalenergy<=0.) || j==0) return;*/
 
 // determination of the final states
-    finalk = SMH[1]*sqrt(finalenergy*(1.+AF[1]*finalenergy));
+    finalk = SMH[Material][1]*sqrt(finalenergy*(1.+alphaK[Material][1]*finalenergy));
     cosinus = 1.-2.*rnd();
     sinus = sqrt(1.-cosinus*cosinus);
     fai = 2.*PI*rnd();
@@ -253,17 +275,18 @@ scat(void)
     KZ = finalk*sinus*sin(fai);
     return;
    }
-// Selection of scattering process in the L-Valley
-// ===================================================
+// Selection of scattering process in the second-Valley
+// ====================================================
   if(IV==2){
     r1 = rnd();
 // Non-Polar optical phonons
 // Emission of an optical phonon
-      if(r1<=SWK[2][1][ie] && j==0){
-         finalenergy=superparticle_energy-GAASHWO;
+      if(r1<=SWK[Material][2][1][ie] && j==0){
+         finalenergy=superparticle_energy-HWO[Material][0];
+         if(finalenergy<0.) return;
          j=1;
 // linea 20
-       kf=SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        f=2.*ki*kf/(ki-kf)/(ki-kf);
        if(f<=0.) return;
        cb=(1.+f-pow((1.+2.*f),rnd()))/f;
@@ -290,11 +313,12 @@ scat(void)
        return;
       }
 // Absorbation of an optical phonon
-      if((r1<=SWK[2][2][ie]) && j==0){
-         finalenergy=superparticle_energy+GAASHWO;
+      if((r1<=SWK[Material][2][2][ie]) && j==0){
+         finalenergy=superparticle_energy+HWO[Material][0];
+         if(finalenergy<0.) return;
          j=1;
 // linea 20
-       kf=SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf=SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        f=2.*ki*kf/(ki-kf)/(ki-kf);
        if(f<=0.) return;
        cb=(1.+f-pow((1.+2.*f),rnd()))/f;
@@ -321,11 +345,12 @@ scat(void)
        return;
       }
 // Emission
-    if((r1<=SWK[2][3][ie]) && j==0){
-       finalenergy=superparticle_energy-GAASHWO;
+    if((r1<=SWK[Material][2][3][ie]) && j==0){
+       finalenergy=superparticle_energy-HWO[Material][0];
+       if(finalenergy<0.) return;
        j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -335,11 +360,12 @@ scat(void)
        return;
     }
 // Absorbation
-    if((r1<=SWK[2][4][ie]) && j==0){
-       finalenergy=superparticle_energy+GAASHWO;
+    if((r1<=SWK[Material][2][4][ie]) && j==0){
+       finalenergy=superparticle_energy+HWO[Material][0];
+       if(finalenergy<0.) return;
        j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -349,13 +375,13 @@ scat(void)
        return;
     }
 // Emission
-    if((r1<=SWK[2][5][ie]) && j==0){
-       finalenergy=superparticle_energy-GAASHWO+EC[2]-EC[1];
+    if((r1<=SWK[Material][2][5][ie]) && j==0){
+       finalenergy=superparticle_energy-HWO[Material][0]+EC[Material][2]-EC[Material][1];
        if(finalenergy<0.) return;
        IV=1;
        j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -365,13 +391,13 @@ scat(void)
        return;
     }
 // Absorbation
-    if((r1<=SWK[2][6][ie]) && j==0){
-       finalenergy=superparticle_energy+GAASHWO+EC[2]-EC[1];
+    if((r1<=SWK[Material][2][6][ie]) && j==0){
+       finalenergy=superparticle_energy+HWO[Material][0]+EC[Material][2]-EC[Material][1];
        if(finalenergy<0.) return;
        IV=1;
        j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -381,12 +407,13 @@ scat(void)
        return;
     }
 // Acoustic phonon emission
-    if((r1<=SWK[2][7][ie]) && j==0){
+    if((r1<=SWK[Material][2][7][ie]) && j==0){
        finalenergy=superparticle_energy;
+       if(finalenergy<0.) return;
        finalk=sqrt(ksquared);
        j=1;
 // determination of the final states
-       kf = SMH[IV]*sqrt(finalenergy*(1.+AF[IV]*finalenergy));
+       kf = SMH[Material][IV]*sqrt(finalenergy*(1.+alphaK[Material][IV]*finalenergy));
        cs = 1.-2.*rnd();
        sn = sqrt(1.-cs*cs);
        fai = 2.*PI*rnd();
@@ -396,8 +423,9 @@ scat(void)
        return;
     }
 // Impurity scattering
-    if((r1<=SWK[2][8][ie]) && j==0){
+    if((r1<=SWK[Material][2][8][ie]) && j==0){
      finalenergy=superparticle_energy;
+     if(finalenergy<0.) return;
      r2=rnd();
      cb=1.-r2/(0.5+(1.-r2)*ksquared/QD2);
      kf=ki;
@@ -421,12 +449,21 @@ scat(void)
      KX=a11*x1+a12*x2+a13*x3;
      KY=a21*x1+a22*x2+a23*x3;
      KZ=a32*x2+a33*x3;
-     return;     
+     return;
     }
-    if((finalenergy<=0.) || j==0) return;
+
+// Impact ionization
+/*    if((r1<=SWK[Material][2][9][ie]) && j==0){
+       ra1=0.5-rnd();
+       ra2=pow(rnd(),2.);
+       finalenergy=bbb*superparticle_energy*(1.0+aaa*ra1*ra2);
+       finalenergy=superparticle_energy-finalenergy;
+       j=1;
+    }
+    if((finalenergy<=0.) || j==0) return;*/
 
 // determination of the final states
-    finalk = SMH[2]*sqrt(finalenergy*(1.+AF[2]*finalenergy));
+    finalk = SMH[Material][2]*sqrt(finalenergy*(1.+alphaK[Material][2]*finalenergy));
     cosinus = 1.-2.*rnd();
     sinus = sqrt(1.-cosinus*cosinus);
     fai = 2.*PI*rnd();
